@@ -37,6 +37,11 @@ pub enum RpcEventKind {
     ErrorReply = RPC_ERROR,
 }
 
+#[inline]
+pub fn rpc_err_str(v: impl fmt::Display) -> Option<Vec<u8>> {
+    Some(v.to_string().as_bytes().to_vec())
+}
+
 impl fmt::Display for RpcEventKind {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(
@@ -560,6 +565,14 @@ impl RpcError {
         Self { code, data }
     }
     #[inline]
+    pub fn code(&self) -> i16 {
+        self.code
+    }
+    #[inline]
+    pub fn data(&self) -> Option<&[u8]> {
+        self.data.as_deref()
+    }
+    #[inline]
     pub fn method(err: Option<Vec<u8>>) -> Self {
         Self {
             code: RPC_ERROR_CODE_METHOD_NOT_FOUND,
